/* this code is for wendy's final fabricademy project, an incubator
 *  I'm using an attiny 44 ssu running on the 1Mhz internal clock with an lcd, a homemade temperature sensor and a homemade heater element.
 *  It uses 97% of the available storage space in a attiny 44ssu, so if you want to add, go larger.
 *  I need the heat to be measured and controlled, and for that to be readable on the LCD screen.
 *  https://www.arduino.cc/en/Reference/VariableDeclaration
 *  https://www.arduino.cc/reference/en/language/functions/digital-io/pinmode/
 *  thanks to Daniel Harmsworth for the support in writing & developing this code
 */

 
#include <LiquidCrystal.h> //I am using the liquid crystal library to help drive the LCD
#include "pinout.h" // I have made a header file so this code can call the pins I've assigned to each operation

//#define TEMPSP 31 // This is a guess for the set point of the temperature sensor as this hasn't been calibrated yet. 
float tempSetpoint = 31;
float temperature = 0; // initialise the temperature with a 0. 
long lastrun = 0;// 'long' was necessary because the attiny was glitching out and running out of room very quickly

LiquidCrystal lcd(5,4,3,2,1,0); //Set up the lcd and tell the Arduino IDE which pins to use, in this case all of the pins on the GND side of the Attiny, except for GND

void setup() {
  //Serial.begin(9600);
  lcd.begin(16, 2);   // set up the number of columns and rows for the LCD
  lcd.print("Initialising..."); //this will print on the screen but if you blink you'll miss it.
  lcd.clear();

  //setting the pins to be inputs or outputs
  pinMode(POT,INPUT); 
  pinMode(TEMP,INPUT);
  pinMode(STATUS,OUTPUT);
  pinMode(HEAT,OUTPUT);
  
  digitalWrite(STATUS, HIGH);//turning the status LED on so that we can see whether the code is behaving the way we want it to
}

void loop() {
  // if it's been 2 seconds since the last time the attiny checked, turn on and off the LED, call the temp control and print to the LCD screen:
    if(millis() - lastrun >= 2000){
      digitalWrite(STATUS, !digitalRead(STATUS));
      getPot();//see what;s going on with the pot
      tempControl(); //call the tempcontrol routine below on heater for defined setpoint.
      lcdPrint(); //print what it found.
      lastrun = millis();//capture the time it last ran, so that we can compare snapshots.
    }
}

void tempControl() {
  // check what's going on on the temp pin, if the temperature is too high, turn off the heater, otherwise, it goes on
  float currentTemp = 210.163-(0.226994*analogRead(TEMP));
  if (currentTemp >= tempSetpoint) {
    digitalWrite(HEAT, LOW);
  } else {
    digitalWrite(HEAT, HIGH);
  }
  temperature = currentTemp;
}

void lcdPrint() {
  //start from the top corner of the LCD, print whatever's in the "", the second one is calling the currentTemp
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("temp: ");
  lcd.print(temperature);
  lcd.setCursor(0,1);
  lcd.print("setPoint: ");
  lcd.print(tempSetpoint);
}

void getPot() {
  //going to call pot value to set the temperature
  int rawPot = analogRead(POT); 
  if (rawPot < 256){
    tempSetpoint = 0;
  } else if (rawPot < 512){
    tempSetpoint = 24;
  } else if (rawPot < 768){
    tempSetpoint = 31;
  } else {
    tempSetpoint = 40;
  }
  
}

